import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class CtrlAltDel(BasicComicModule):
    latestUrl = 'http://www.ctrlaltdel-online.com/index.php?t=archives&date=last'
    imageUrl = 'http://www.ctrlaltdel-online.com/?t=archives&date=%s'
    imageSearch = re.compile(r'<img src="(\.?/images/comics/\d{8}\..+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'<a href="\.?(/\?t=archives&date=\d{4}-\d{2}-\d{2})"><img src="\.?/images/nav_back.gif"', re.IGNORECASE)
    help = 'Index format: yyyy-mm-dd'
